FaradayIO Toolset Documentation
================

The Faraday IO toolset is a collection of Python scripts that perform input/output, packet creation, packet parsing, and other functions that provide a basic level of interaction with a Faraday digital radio. This module is specifically designed to be used in the creation of applications that wish to interact with a Faraday device over the localhost proxy server RESTful API.


.. toctree::
	:caption: Toolsets
	:maxdepth: 1
	
	faradayio
	faradaycommands
	commandmodule
	cc430radioconfig
	checksum
	deviceconfig
	gpioallocations
	telemetryparser